@@ -32,22 +32,32 @@
     (success :foreground success)
     ;;;; font-lock-* faces
     (font-lock-builtin-face              :foreground builtin)
-    (font-lock-comment-face              :foreground comments)
+    (font-lock-bracket-face              :inherit 'font-lock-punctuation-face)
     (font-lock-comment-delimiter-face    :inherit 'font-lock-comment-face)
-    (font-lock-doc-face                  :inherit 'font-lock-comment-face :foreground doc-comments)
+    (font-lock-comment-face              :foreground comments)
     (font-lock-constant-face             :foreground constants)
+    (font-lock-doc-face                  :inherit 'font-lock-comment-face :foreground doc-comments)
+    (font-lock-delimiter-face            :inherit 'font-lock-punctuation-face)
+    (font-lock-escape-face               :inherit 'font-lock-regexp-grouping-backslash)
     (font-lock-function-name-face        :foreground functions)
+    (font-lock-function-call-face        :inherit 'font-lock-function-name-face :slant 'italic :foreground (doom-blend 'functions 'fg 0.7))
     (font-lock-keyword-face              :foreground keywords)
+    (font-lock-misc-punctuation-face     :inherit 'font-lock-punctuation-face)
+    (font-lock-negation-char-face        :inherit 'bold :foreground operators)
+    (font-lock-number-face               :foreground numbers)
+    (font-lock-operator-face             :foreground operators)
+    (font-lock-punctuation-face          :foreground (doom-blend 'operators 'fg 0.25))
+    (font-lock-property-name-face        :foreground (doom-blend 'keywords 'fg 0.6) :weight 'bold)
+    (font-lock-property-use-face         :inherit 'font-lock-property-name-face :weight 'regular)
+    (font-lock-preprocessor-char-face    :inherit 'bold :foreground operators)
+    (font-lock-preprocessor-face         :inherit 'bold :foreground operators)
+    (font-lock-regexp-grouping-backslash :inherit 'bold :foreground operators)
+    (font-lock-regexp-grouping-construct :inherit 'bold :foreground operators)
     (font-lock-string-face               :foreground strings)
     (font-lock-type-face                 :foreground type)
     (font-lock-variable-name-face        :foreground variables)
-    (font-lock-number-face               :foreground numbers)
+    (font-lock-variable-use-face         :inherit 'font-lock-variable-name-face :foreground (doom-blend 'variables 'fg 0.5))
     (font-lock-warning-face              :inherit 'warning)
-    (font-lock-negation-char-face        :inherit 'bold :foreground operators)
-    (font-lock-preprocessor-face         :inherit 'bold :foreground operators)
-    (font-lock-preprocessor-char-face    :inherit 'bold :foreground operators)
-    (font-lock-regexp-grouping-backslash :inherit 'bold :foreground operators)
-    (font-lock-regexp-grouping-construct :inherit 'bold :foreground operators)
     ;;;; mode-line / header-line
     (mode-line           :background bg     :foreground fg     :distant-foreground bg)
     (mode-line-active    :inherit 'mode-line)
@@ -410,7 +420,7 @@
     (diff-hunk-header :foreground violet)
     (diff-indicator-added :foreground vc-added)
     (diff-indicator-changed :foreground vc-modified)
-    (diff-indicator-removed :foreground vc-added)
+    (diff-indicator-removed :foreground vc-deleted)
     (diff-refine-added   :inherit 'diff-added :inverse-video t)
     (diff-refine-changed :inherit 'diff-changed :inverse-video t)
     (diff-refine-removed :inherit 'diff-removed :inverse-video t)
@@ -1349,7 +1359,7 @@
     ;;;; solaire-mode
     (solaire-default-face  :inherit 'default :background bg-alt)
     (solaire-hl-line-face  :inherit 'hl-line :background bg :extend t)
-    (solaire-org-hide      :inherit 'org-hide :foreground bg-alt)
+    (solaire-org-hide-face :inherit 'org-hide :foreground bg-alt)
     ;;;; spaceline
     (spaceline-highlight-face   :background highlight)
     (spaceline-modified         :background vc-modified)
